@@ -42,11 +42,7 @@ class CaseEventHandler(object):
             verb="assign",
             subject=case["display_name"],
         )
-        LOG.info(
-            "Updating {0} to be assigned with {1}".format(
-                case["display_name"], user["name"]
-            )
-        )
+        LOG.info("Updating {0} to be assigned with {1}".format(case["display_name"], user["name"]))
 
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
@@ -73,9 +69,7 @@ class CaseEventHandler(object):
             updated_case (dict): The updated case
         """
         LOG.info(
-            "Creating event for unassigning {0} from {1}".format(
-                user["name"], case["display_name"]
-            )
+            "Creating event for unassigning {0} from {1}".format(user["name"], case["display_name"])
         )
 
         self.create_event(
@@ -89,9 +83,7 @@ class CaseEventHandler(object):
         )
 
         LOG.info(
-            "Updating {0} to be unassigned with {1}".format(
-                case["display_name"], user["name"]
-            )
+            "Updating {0} to be unassigned with {1}".format(case["display_name"], user["name"])
         )
 
         # if case is not prioritized and user wishes to inactivate it:
@@ -131,9 +123,7 @@ class CaseEventHandler(object):
             return None
 
         LOG.info(
-            "Creating event for updating status of {0} to {1}".format(
-                case["display_name"], status
-            )
+            "Creating event for updating status of {0} to {1}".format(case["display_name"], status)
         )
 
         # assign case to user if user unarchives it
@@ -178,8 +168,7 @@ class CaseEventHandler(object):
             updated_case
         """
         LOG.info(
-            "Creating event for updating the synopsis for case"
-            " {0}".format(case["display_name"])
+            "Creating event for updating the synopsis for case" " {0}".format(case["display_name"])
         )
 
         self.create_event(
@@ -226,9 +215,7 @@ class CaseEventHandler(object):
             subject=case["display_name"],
         )
 
-        LOG.info(
-            "Change status for case {0} to 'archived'".format(case["display_name"])
-        )
+        LOG.info("Change status for case {0} to 'archived'".format(case["display_name"]))
 
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
@@ -250,10 +237,7 @@ class CaseEventHandler(object):
         Returns:
             updated_case(dict)
         """
-        LOG.info(
-            "Creating event for opening research for case"
-            " {0}".format(case["display_name"])
-        )
+        LOG.info("Creating event for opening research for case" " {0}".format(case["display_name"]))
 
         self.create_event(
             institute=institute,
@@ -265,9 +249,7 @@ class CaseEventHandler(object):
             subject=case["display_name"],
         )
 
-        LOG.info(
-            "Set research_requested for case {0} to True".format(case["display_name"])
-        )
+        LOG.info("Set research_requested for case {0} to True".format(case["display_name"]))
 
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
@@ -328,7 +310,7 @@ class CaseEventHandler(object):
             updated_case
         """
         if collaborator_id in case.get("collaborators", []):
-            raise ValueError("new customer is already a collaborator")
+            raise ValueError(f"{collaborator_id} is already a collaborator.")
 
         self.create_event(
             institute=institute,
@@ -529,9 +511,7 @@ class CaseEventHandler(object):
             subject=status,
         )
 
-        LOG.info(
-            "Updating {0}'s checked status {1}".format(case["display_name"], status)
-        )
+        LOG.info("Updating {0}'s checked status {1}".format(case["display_name"], status))
         analysis_checked = False if unmark else True
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
@@ -565,9 +545,7 @@ class CaseEventHandler(object):
             subject=case_obj["display_name"],
         )
 
-        LOG.info(
-            "Update HPO clinical filter status for {}".format(case_obj["display_name"])
-        )
+        LOG.info("Update HPO clinical filter status for {}".format(case_obj["display_name"]))
 
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case_obj["_id"]},
@@ -577,9 +555,7 @@ class CaseEventHandler(object):
         LOG.debug("Case updated")
         return updated_case
 
-    def update_default_panels(
-        self, institute_obj, case_obj, user_obj, link, panel_objs
-    ):
+    def update_default_panels(self, institute_obj, case_obj, user_obj, link, panel_objs):
         """Update default panels for a case.
 
         Arguments:
