@@ -473,12 +473,22 @@ def parse_case(config):
         raise ConfigError("A case has to have a 'family'")
 
     individuals = parse_individuals(config["samples"])
+    synopsis = None
+    if config.get("synopsis"):
+        synopsis = (
+            ". ".join(config["synopsis"])
+            if isinstance(config["synopsis"], list)
+            else config["synopsis"]
+        )
 
     case_data = {
         "owner": config["owner"],
         "collaborators": [config["owner"]],
         "case_id": config["family"],
         "display_name": config.get("family_name", config["family"]),
+        "synopsis": synopsis,
+        "phenotype_terms": config.get("phenotype_terms"),
+        "cohorts": config.get("cohorts"),
         "genome_build": config.get("human_genome_build"),
         "lims_id": config.get("lims_id"),
         "rank_model_version": str(config.get("rank_model_version", "")),
