@@ -8,9 +8,7 @@ def test_update_individuals_table(app, case_obj, institute_obj):
     with app.test_client() as client:
 
         # WHEN collecting the individuals_table jinja macro
-        macro = get_template_attribute(
-            "cases/individuals_table.html", "individuals_table"
-        )
+        macro = get_template_attribute("cases/individuals_table.html", "individuals_table")
 
         # and passing to it the required parameters
         html = macro(case_obj, institute_obj, SAMPLE_SOURCE)
